import * as pulumi from "@pulumi/pulumi";
/**
 * Provides a GitHub issue label resource.
 *
 * This resource allows you to create and manage issue labels within your
 * GitHub organization.
 *
 * Issue labels are keyed off of their "name", so pre-existing issue labels result
 * in a 422 HTTP error if they exist outside of Pulumi. Normally this would not
 * be an issue, except new repositories are created with a "default" set of labels,
 * and those labels easily conflict with custom ones.
 *
 * This resource will first check if the label exists, and then issue an update,
 * otherwise it will create.
 *
 * ## Example Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * // Create a new, red colored label
 * const testRepo = new github.IssueLabel("test_repo", {
 *     repository: "test-repo",
 *     name: "Urgent",
 *     color: "FF0000",
 * });
 * ```
 *
 * ## Import
 *
 * GitHub Issue Labels can be imported using an ID made up of `repository:name`, e.g.
 *
 * ```sh
 * $ pulumi import github:index/issueLabel:IssueLabel panic_label terraform:panic
 * ```
 */
export declare class IssueLabel extends pulumi.CustomResource {
    /**
     * Get an existing IssueLabel resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: IssueLabelState, opts?: pulumi.CustomResourceOptions): IssueLabel;
    /**
     * Returns true if the given object is an instance of IssueLabel.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IssueLabel;
    /**
     * A 6 character hex code, **without the leading #**, identifying the color of the label.
     */
    readonly color: pulumi.Output<string>;
    /**
     * A short description of the label.
     */
    readonly description: pulumi.Output<string | undefined>;
    readonly etag: pulumi.Output<string>;
    /**
     * The name of the label.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The GitHub repository
     */
    readonly repository: pulumi.Output<string>;
    /**
     * The URL to the issue label
     */
    readonly url: pulumi.Output<string>;
    /**
     * Create a IssueLabel resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IssueLabelArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering IssueLabel resources.
 */
export interface IssueLabelState {
    /**
     * A 6 character hex code, **without the leading #**, identifying the color of the label.
     */
    color?: pulumi.Input<string>;
    /**
     * A short description of the label.
     */
    description?: pulumi.Input<string>;
    etag?: pulumi.Input<string>;
    /**
     * The name of the label.
     */
    name?: pulumi.Input<string>;
    /**
     * The GitHub repository
     */
    repository?: pulumi.Input<string>;
    /**
     * The URL to the issue label
     */
    url?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a IssueLabel resource.
 */
export interface IssueLabelArgs {
    /**
     * A 6 character hex code, **without the leading #**, identifying the color of the label.
     */
    color: pulumi.Input<string>;
    /**
     * A short description of the label.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the label.
     */
    name?: pulumi.Input<string>;
    /**
     * The GitHub repository
     */
    repository: pulumi.Input<string>;
}
