import * as pulumi from "@pulumi/pulumi";
/**
 * This resource allows you to create and manage a specific custom property for a GitHub repository.
 *
 * ## Example Usage
 *
 * > Note that this assumes there already is a custom property defined on the org level called `my-cool-property` of type `string`
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as github from "@pulumi/github";
 *
 * const example = new github.Repository("example", {
 *     name: "example",
 *     description: "My awesome codebase",
 * });
 * const string = new github.RepositoryCustomProperty("string", {
 *     repository: example.name,
 *     propertyName: "my-cool-property",
 *     propertyType: "string",
 *     propertyValues: ["test"],
 * });
 * ```
 *
 * ## Import
 *
 * GitHub Repository Custom Property can be imported using an ID made up of a comibnation of the names of the organization, repository, custom property separated by a `:` character, e.g.
 *
 * ```sh
 * $ pulumi import github:index/repositoryCustomProperty:RepositoryCustomProperty example <organization-name>:<repo-name>:<custom-property-name>
 * ```
 */
export declare class RepositoryCustomProperty extends pulumi.CustomResource {
    /**
     * Get an existing RepositoryCustomProperty resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: RepositoryCustomPropertyState, opts?: pulumi.CustomResourceOptions): RepositoryCustomProperty;
    /**
     * Returns true if the given object is an instance of RepositoryCustomProperty.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RepositoryCustomProperty;
    /**
     * Name of the custom property. Note that a pre-requisiste for this resource is that a custom property of this name has already been defined on the organization level
     */
    readonly propertyName: pulumi.Output<string>;
    /**
     * Type of the custom property. Can be one of `singleSelect`, `multiSelect`, `string`, or `trueFalse`
     */
    readonly propertyType: pulumi.Output<string>;
    /**
     * Value of the custom property in the form of an array. Properties of type `singleSelect`, `string`, and `trueFalse` are represented as a string array of length 1
     */
    readonly propertyValues: pulumi.Output<string[]>;
    /**
     * The repository of the environment.
     */
    readonly repository: pulumi.Output<string>;
    /**
     * Create a RepositoryCustomProperty resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RepositoryCustomPropertyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering RepositoryCustomProperty resources.
 */
export interface RepositoryCustomPropertyState {
    /**
     * Name of the custom property. Note that a pre-requisiste for this resource is that a custom property of this name has already been defined on the organization level
     */
    propertyName?: pulumi.Input<string>;
    /**
     * Type of the custom property. Can be one of `singleSelect`, `multiSelect`, `string`, or `trueFalse`
     */
    propertyType?: pulumi.Input<string>;
    /**
     * Value of the custom property in the form of an array. Properties of type `singleSelect`, `string`, and `trueFalse` are represented as a string array of length 1
     */
    propertyValues?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The repository of the environment.
     */
    repository?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a RepositoryCustomProperty resource.
 */
export interface RepositoryCustomPropertyArgs {
    /**
     * Name of the custom property. Note that a pre-requisiste for this resource is that a custom property of this name has already been defined on the organization level
     */
    propertyName: pulumi.Input<string>;
    /**
     * Type of the custom property. Can be one of `singleSelect`, `multiSelect`, `string`, or `trueFalse`
     */
    propertyType: pulumi.Input<string>;
    /**
     * Value of the custom property in the form of an array. Properties of type `singleSelect`, `string`, and `trueFalse` are represented as a string array of length 1
     */
    propertyValues: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The repository of the environment.
     */
    repository: pulumi.Input<string>;
}
